/*
 * #%L
 * *********************************************************************************************************************
 * 
 * SolidBlue - open source safe data
 * http://solidblue.tidalwave.it - hg clone https://bitbucket.org/tidalwave/solidblue-src
 * %%
 * Copyright (C) 2011 - 2013 Tidalwave s.a.s. (http://tidalwave.it)
 * %%
 * *********************************************************************************************************************
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 * 
 * *********************************************************************************************************************
 * 
 * $Id$
 * 
 * *********************************************************************************************************************
 * #L%
 */
package it.tidalwave.integritychecker.ui.impl.netbeans;

import javax.annotation.Nonnull;
import javafx.fxml.FXML;
import javafx.scene.control.Label;
import javafx.scene.control.ProgressBar;
import javafx.application.Platform;
import it.tidalwave.integritychecker.ui.IntegrityCheckerFieldsBean;
import it.tidalwave.integritychecker.ui.IntegrityCheckerPresentation;

/***********************************************************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
public class JFXIntegrityCheckerPresentation implements IntegrityCheckerPresentation
  {
    @FXML
    private Label lbElapsedTime;
    
    @FXML
    private Label lbEstimatedRemainingTime;
    
    @FXML
    private Label lbTotalData;
    
    @FXML
    private Label lbProcessedData;
    
    @FXML
    private Label lbSpeed;
    
    @FXML
    private ProgressBar pbProgress;
    
    @FXML
    private Label lbProgress;
    
    public void initialize()
      {
        populate(new IntegrityCheckerFieldsBean());
      }

    @Override
    public void renderBeginOfScan()
      {
        Platform.runLater(new Runnable() // FIXME: use an extension of SwingSafeProxy to handle threading
          {
            @Override
            public void run() 
              {
                assert Platform.isFxApplicationThread();
                pbProgress.setProgress(-1); // indeterminate
              }
          });
      }

    @Override
    public void populate (final @Nonnull IntegrityCheckerFieldsBean fields)
      {
        Platform.runLater(new Runnable() // FIXME: use an extension of SwingSafeProxy to handle threading
          {
            @Override
            public void run() 
              {
                assert Platform.isFxApplicationThread();
                lbTotalData.setText(fields.getTotal());
                lbProcessedData.setText(fields.getProcessed());
                lbElapsedTime.setText(fields.getElapsedTime());
                lbEstimatedRemainingTime.setText(fields.getRemainingTime());
                lbSpeed.setText(fields.getSpeed());
                final double progress = fields.getProgress();
                final boolean indeterminate = (progress == 0) && (pbProgress.getProgress() < 0);
                pbProgress.setProgress(indeterminate ? -1 : progress);
                lbProgress.setText(indeterminate || (progress == 0) ? "" : String.format("%.1f %%", 100 * progress));
              }
          });
      }
  }