/*
 * #%L
 * *********************************************************************************************************************
 * 
 * SolidBlue - open source safe data
 * http://solidblue.tidalwave.it - hg clone https://bitbucket.org/tidalwave/solidblue-src
 * %%
 * Copyright (C) 2011 - 2013 Tidalwave s.a.s. (http://tidalwave.it)
 * %%
 * *********************************************************************************************************************
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 * 
 * *********************************************************************************************************************
 * 
 * $Id$
 * 
 * *********************************************************************************************************************
 * #L%
 */
package it.tidalwave.netbeans.javafx;

import javax.annotation.Nonnull;
import java.io.IOException;
import java.net.URL;
import java.awt.Color;
import javafx.fxml.FXMLLoader;
import javafx.fxml.JavaFXBuilderFactory;
import javafx.scene.Parent;
import javafx.scene.Scene;
import javafx.embed.swing.JFXPanel;
import javafx.application.Platform;
import lombok.Getter;
import lombok.extern.slf4j.Slf4j;

/***********************************************************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
@Slf4j
public class JFXAdapter<T> extends JFXPanel
  {
    private final Object lock = new Object();
    
    @Getter
    private volatile T presentation;
    
    public JFXAdapter (final @Nonnull Class<T> ownerClass)
      {
        setOpaque(false);

        Platform.setImplicitExit(false);
        Platform.runLater(new Runnable() 
          {
            @Override
            public void run() 
              {
                createScene(ownerClass);
              }
          });
        
        synchronized (lock)
          {
            while (presentation == null)
              {
                try 
                  {
                    lock.wait();
                  }
                catch (InterruptedException e)
                  {
                    throw new RuntimeException(e);
                  }
              }
          }
      }
    
    private void createScene (final @Nonnull Class<?> ownerClass)
      {
        try 
          {
            assert Platform.isFxApplicationThread();
            final URL url = ownerClass.getResource(ownerClass.getSimpleName() + ".fxml");
            final FXMLLoader fxmlLoader = new FXMLLoader(url, null, new JavaFXBuilderFactory());
            final Parent root = (Parent)fxmlLoader.load(); 
            setScene(new Scene(root));
            
            synchronized (lock)
              {
                presentation = fxmlLoader.getController();
                lock.notifyAll();
              }
          } 
        catch (IOException e)
          {
            log.error("", e);
          }
      }

//    @Nonnull
//    private static IntegrityCheckerPresentation createContent()
//      {
//        return Utilities.isMac() ? new MacOSXIntegrityCheckerPresentationPanel() : new IntegrityCheckerPresentationPanel();
//      }

  }
